@@ -1,8 +1,8 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "scpaste" "0.7.0"
+(define-package "scpaste" "20250706.1759"
   "Paste to the web via scp."
   '((htmlize "1.39"))
   :url "https://git.sr.ht/~technomancy/scpaste"
-  :commit "4723c551951c5e86ceaf078846f4f46db38739fe"
-  :revdesc "0.7.0-0-g4723c551951c"
+  :commit "5203d3625c34e51433435dc466853aa36f4ebe21"
+  :revdesc "5203d3625c34"
   :keywords '("convenience" "hypermedia"))
